#
# spec file for package geotiff
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover   2
%define libname lib%{name}%{sover}
Name:           geotiff
Version:        1.4.2
Release:        lp150.1.3
Summary:        Library to handle georeferenced TIFF
License:        MIT and SUSE-Public-Domain
Group:          Productivity/Scientific/Other
Url:            http://trac.osgeo.org/geotiff
Source0:        http://download.osgeo.org/%{name}/lib%{name}/lib%{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  libjpeg-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(proj)
BuildRequires:  pkgconfig(zlib)

%description
This library is designed to permit the extraction and parsing of the
"GeoTIFF" Key directories, as well as definition and installation of
GeoTIFF keys in new files.

%package devel
Summary:        GeoTIFF header files
Group:          Development/Libraries/C and C++
Provides:       lib%{name}-devel = %{version}
Requires:       %{libname} = %{version}
Requires:       pkgconfig(libtiff-4)
Requires:       pkgconfig(proj)

%description devel
Header files for GeoTIFF library.

This library is designed to permit the extraction and parsing of the
"GeoTIFF" Key directories, as well as definition and installation of
GeoTIFF keys in new files.

%package -n %{libname}
Summary:        Shared libraries for GeoTIFF library
Group:          System/Libraries

%description -n %{libname}
Shared libraries for GeoTIFF library.

This library is designed to permit the extraction and parsing of the
"GeoTIFF" Key directories, as well as definition and installation of
GeoTIFF keys in new files.

%prep

%setup -q -n lib%{name}-%{version}
for f in `find . -type f` ; do
	if file $f | grep -q ISO-8859 ; then
		echo "Fix encoding for $f"
		set -x
		iconv -f ISO-8859-1 -t UTF-8 $f > ${f}.tmp && \
			mv -f ${f}.tmp $f
		set +x
	fi
	if file $f | grep -q CRLF ; then
		echo "Fix line ends for $f"
		set -x
		sed -i -e 's|\r||g' $f
		set +x
	fi
done

%build
export CFLAGS="%{optflags} $CFLAGS -g -fstack-protector -fno-strict-aliasing -D _BSD_SOURCE"
export CXXFLAGS="%{optflags} $CXXFLAGS -g -fstack-protector -fno-strict-aliasing"
%configure \
	--prefix=%{_prefix} \
	--includedir=%{_includedir}/lib%{name} \
	--with-proj \
	--with-jpeg \
	--with-zip \
	--with-pic \
	--enable-static=no \
	--enable-debug=yes
make %{?_smp_mflags}

%install
%make_install

# install pkgconfig file
cat > libgeotiff.pc <<EOF
prefix=%{_prefix}
exec_prefix=%{_prefix}
libdir=%{_libdir}
includedir=%{_includedir}/lib%{name}

Name:           %{libname}
Version:        %{version}
Description: GeoTIFF file format library
Libs: -L%{_libdir} -llib%{name}
Cflags: -I%{_includedir}/lib%{name}
EOF
install -dm 755 %{buildroot}%{_libdir}/pkgconfig
install -p -m 644 lib%{name}.pc %{buildroot}%{_libdir}/pkgconfig
echo  >> %{buildroot}%{_datadir}/epsg_csv/codes.csv
# do not ship la files
find %{buildroot}%{_libdir} -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc ChangeLog LICENSE README COPYING
%{_bindir}/geotifcp
%{_bindir}/listgeo
%{_bindir}/applygeo
%{_mandir}/man1/listgeo.1%{ext_man}
%{_mandir}/man1/applygeo.1%{ext_man}
%{_mandir}/man1/geotifcp.1%{ext_man}
%dir %{_datadir}/epsg_csv
%attr(0755,root,root) %{_datadir}/epsg_csv/csv2c.py*
%attr(0755,root,root) %{_datadir}/epsg_csv/csv_tools.py*
%attr(0644,root,root) %{_datadir}/epsg_csv/*.csv

%files -n %{libname}
%defattr(-,root,root)
%doc ChangeLog LICENSE README COPYING
%{_libdir}/lib%{name}.so.%{sover}*

%files devel
%defattr(0644,root,root,0755)
%doc ChangeLog LICENSE README COPYING
%dir %{_includedir}/lib%{name}
%{_includedir}/lib%{name}/*.h
%{_includedir}/lib%{name}/*.inc
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/lib%{name}.pc

%changelog
* Sun Mar 12 2017 mpluskal@suse.com
- Small packaging cleanup
- Prepare version update for Leap and backports (boo#1029595)
* Sat Oct  1 2016 tzotsos@opensuse.org
- Update to 1.4.2
  * update to EPSG v8.9 database
  * cleanups and security fixes
* Fri Sep 30 2016 tzotsos@opensuse.org
- Switched download link to OSGeo server
* Tue Jul  5 2016 toddrme2178@gmail.com
- Fix Group tag.
* Sat May  9 2015 mpluskal@suse.com
- Do not build or ship static libraries and .la files
- Remove useless conditions
* Sat Jan 31 2015 mpluskal@suse.com
- Cleanup spec file using spec-cleaner
- Remove commented out patch
- Add build dependency on graphviz to enable images in
  documentation
- Add build dependency on pkg-config to enable dependency generation
  of .pc file
- Update to 1.4.1
  * CMake: Fix up SONAME and VERSION to better
    match configure.ac
  * csv/datum_shift_pref.csv: revert change in preferred datum shift
    for Pulkovo 1942(58) related to ticket #1851 - not appropriate.
  * Preparing 1.4.1 release.
  * csv/datum_shift_pref.csv: Update Pulkova 1942(58) to use a
    particular transformation (#52).
  * bin/geotifcp.c: added B, L, C and M flags from tiffcp (#68)"
  * geo_print.c: clarify that the buffer passed to read methods is only
    guaranteed to be 1024 bytes long (#62).
  * CMake: Support for INCODE build. If you need INCODE support,
    with the definitions compiled into headers, use CMake as your
    configuration/build platform.
  * csv: Override three Brazilian datum shifts on behalf of Daniel
    Miranda and the OSGeo Brazilian Chapter.
  * csv: Upgrade to EPSG 8.5
  * INCODE: Adapt Ben Adler's patch in #66 to add INCODE support to the
    CMake configuration
  * geo_normalize.c: #59, better Mercator_2SP support
  * geotifcp: Do not segfault when a TIFF file has WhitePoint set #65
  * geo_names.c: fix #67 -- add VerticalUnitsGeoKey
  * add_esri_column.py: manually replace D_SIRGAS-Chile by D_Peru96 for GCS_Peru96. Likely an error in the FileGDB SDK db (#63)
  * csv: Upgrade to EPSG 8.4
  * tiffcp: Add bigtiff output support with the -8 flag like tiffcp.  Contributed by
    Mohannad Al-Durgham (nwgeo.com).
  * csv: Upgrade to EPSG 8.2
  * csv/datum_shift_pref.csv: Force OSGB 1936 preferred datum shift.
    (http://trac.osgeo.org/gdal/ticket/4597)
* Fri Jun 15 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- Fix in pkgconfig file
* Sat May 26 2012 Angelos Tzotsos <tzotsos@opensuse.org>
- Updated to 1.4.0
* Thu Mar 22 2012 Michael Behrisch <behrisch@users.sf.net>
- added gcc build dependency
- removed unneeded data dir fix for non-Suse
* Mon Apr 11 2011 Rene van Paassen<rene.vanpaassen@gmail.com>
- removed now superfluous "%%exclude %%{_libdir}/debug" for i586
* Sat Apr  9 2011 Hans-Peter Jansen <hpj@urpla.net>
- fix 64 bit issues, enable debug
* Thu Jul  8 2010 Dirk Stöcker <opensuse@dstoecker.de> 1.3.0
- Updated to 1.3.0
* Fri Jun 26 2009 Dirk Stöcker <opensuse@dstoecker.de> 1.2.5
- Updated to 1.2.5
- Using parts of spec file from PackMan for improved quality
* Mon Jun  9 2008 Dirk Stöcker <opensuse@dstoecker.de> 1.2.4
- SPEC file created for openSUSE build service
* Sat Jul 14 2007 judas_iscariote@shorewall.net
- spec file cleanup
  Mon Jun 19 12:00:00 UTC 2006 - Tim Fischer
- SPEC file created for SUSE 10.1
